Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/jpa2/context/java/JavaPersistentAttribute2_0.java')
-rw-r--r--jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/jpa2/context/java/JavaPersistentAttribute2_0.java25
1 files changed, 5 insertions, 20 deletions
diff --git a/jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/jpa2/context/java/JavaPersistentAttribute2_0.java b/jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/jpa2/context/java/JavaPersistentAttribute2_0.java
index 6e50f76aeb..4267d513e3 100644
--- a/jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/jpa2/context/java/JavaPersistentAttribute2_0.java
+++ b/jpa/plugins/org.eclipse.jpt.core/src/org/eclipse/jpt/core/jpa2/context/java/JavaPersistentAttribute2_0.java
@@ -1,5 +1,5 @@
/*******************************************************************************
- * Copyright (c) 2009 Oracle. All rights reserved.
+ * Copyright (c) 2009, 2010 Oracle. All rights reserved.
* This program and the accompanying materials are made available under the
* terms of the Eclipse Public License v1.0, which accompanies this distribution
* and is available at http://www.eclipse.org/legal/epl-v10.html.
@@ -10,9 +10,10 @@
package org.eclipse.jpt.core.jpa2.context.java;
import org.eclipse.jpt.core.context.java.JavaPersistentAttribute;
+import org.eclipse.jpt.core.jpa2.context.PersistentAttribute2_0;
/**
* JPA 2.0 Java persistent attribute (field or property)
* <p>
* Provisional API: This interface is part of an interim API that is still
* under development and expected to change significantly before reaching
@@ -21,23 +22,7 @@ import org.eclipse.jpt.core.context.java.JavaPersistentAttribute;
* will almost certainly be broken (repeatedly) as the API evolves.
*/
public interface JavaPersistentAttribute2_0
- extends JavaPersistentAttribute
+ extends JavaPersistentAttribute, PersistentAttribute2_0
{
- /**
- * Return the name of the container type to be used in the metamodel field
- * declaration corresponding to the attribute's mapping.
- */
- String getMetamodelContainerFieldTypeName();
-
- /**
- * Return the name of the container map key type to be used in the
- * metamodel field declaration corresponding to the attribute's mapping.
- * Return null if the attribute's type is not {@link java.util.Map}.
- */
- String getMetamodelContainerFieldMapKeyTypeName();
-
- /**
- * Return the attribute's type name for the metamodel.
- */
- String getMetamodelTypeName();
+ // nothing yet...
}

Back to the top
@@ -10,9 +10,10 @@
/**
- * JPA 2.0 Java persistent attribute (field or property)
+ * JPA 2.0 context Java persistent attribute (field or property)
* <p>
* Provisional API: This interface is part of an interim API that is still